// @ts-nocheck
import { useState, useEffect } from 'react'
import clsx from 'clsx'
import styled from 'styled-components'
import logoImg from '../assets/images/logo.png'
import colorLogoImg from '../assets/images/logo_color.png'
import Nav from './Nav'

export default function Header () {
  const [scrollY, setScrollY] = useState(0)

  const handleScroll = () => {
    const offset = window.scrollY

    setScrollY(offset)
  }

  useEffect(() => {
    window.addEventListener('scroll', handleScroll)

    return () => {
      window.removeEventListener('scroll', handleScroll)
    }
  }, [])

  return (
    <Wrapper className={clsx({ active: scrollY > 10 })}>
      <LogoWrap>
        <Logo className={clsx({ active: scrollY > 10 })} image={ scrollY > 10 ? colorLogoImg : logoImg} />
        <LogoTitpeWrap>
          <LogoTitle type='main'>SWLab</LogoTitle>
          <LogoTitle type='sub'>Bankware Global</LogoTitle>
        </LogoTitpeWrap>
      </LogoWrap>
      <Nav />
    </Wrapper>
  )
}

const Wrapper = styled.div`
    display: flex;
    align-items: center;
    height: 8.125rem;
    max-height: 8.125rem;
    padding: 1.875rem 5rem;
    background-color: rgba(0, 0, 0, 0);
    position: fixed;
    top: 0;
    right: 0;
    left: 0;
    z-index: 100;
    color: #fff;

    &.active {
      background-color: #fff;
      box-shadow: 0 6px 9px 0 rgba(0, 0, 0, .16);
      color: #0072CE;
      padding: .5rem 5rem;
      max-height: 5.5rem;
      transition: background-color 1s, box-shadow .2s, max-height .8s;
    }
`
const Logo = styled.div`
    margin-top: 10px;
    margin-right: 6px;
    width: 35px;
    height: 44px;
    background-image: url(${props => props.image});
    background-size: contain;
    background-repeat: no-repeat;

    &.active {
      width: 52px;
      height: 52px;
    }
`
const LogoWrap = styled.div`
    display: flex;
    align-items: center;
    flex-grow: 1;
    width: 300px;
    height: 60px;
    margin-top: -8px;
`
const LogoTitpeWrap = styled.div`
    display: flex;
    flex-direction: column;
`
const LogoTitle = styled.span`
    font-size: ${(props) => (props.type === 'main' ? '33px' : '14px')};
    font-weight: ${(props) => (props.type === 'main' ? 600 : 400)};
    margin-top: ${(props) => (props.type !== 'main' && '-4px')}
`
